@@ -26,12 +26,14 @@ import logging
 import os
 from os.path import expanduser
 import sys
+import traceback
 
 import six.moves.urllib.parse as urlparse
 
 import glanceclient
 from glanceclient.common import utils
 from glanceclient import exc
+from glanceclient.openstack.common.gettextutils import _
 from glanceclient.openstack.common import importutils
 from glanceclient.openstack.common import strutils
 
@@ -588,6 +590,12 @@ class OpenStackImagesShell(object):
             args.func(client, args)
         except exc.Unauthorized:
             raise exc.CommandError("Invalid OpenStack Identity credentials.")
+        except Exception:
+            #NOTE(kragniz) Print any exceptions raised to stderr if the --debug
+            # flag is set
+            if args.debug:
+                traceback.print_exc()
+            raise
         finally:
             if profile:
                 trace_id = osprofiler_profiler.get().get_base_id()
